@@ -6,10 +6,9 @@ from requests.auth import HTTPBasicAuth
 import random
 
 class kcspark():
-    def __init__(self,host,user,password,**kw):
+    def __init__(self,host,user,**kw):
         self.host=host
         self.user=user
-        self.password=password
         self.client = InsecureClient(f'http://{host}:50070', user='livy')
         for k,w in kw.items():
             setattr(self,k,w)
@@ -31,23 +30,40 @@ class kcspark():
         seq=''.join(random.choices(list('ABCDEFGHJKLMNPQRSTUVWXYZ12345678901234567890'), k=5))
         livyname=f"""{self.user}川A{seq}"""   
         LIVY_SERVER = f"http://{self.host}:8998"
-        auth = HTTPBasicAuth(self.user,self.password)
+        #auth = HTTPBasicAuth(self.user,self.password)
         path=f'hdfs:///user/{self.user}/{seq}'
         df_=pd.DataFrame()
-        try:
-            with LivySession.create(LIVY_SERVER,
-                                    auth=auth,
-                                    verify=False,
-                                    name=livyname,
-                                    driver_memory="10g"
-                                   ) as session:
-                    session.run(f"""df=spark.sql('''{sql}''')""")
-                    session.run(f"""df.repartition(1).write.format('com.databricks.spark.csv').mode('overwrite').option("sep","|").save('{path}',header = 'true',emptyValue='')""")
-                    df_=self.hdfs2df(path[7:])
-        except:
-            print('查询失败')
-            df_='查询失败'
+        with LivySession.create(LIVY_SERVER,
+                                #auth=auth,
+                                verify=False,
+                                name=livyname,
+                                driver_memory="10g"
+                               ) as session:
+            try:
+                session.run(f"""df=spark.sql('''{sql}''')""")
+                session.run(f"""df.repartition(1).write.format('com.databricks.spark.csv').mode('overwrite').option("sep","|").save('{path}',header = 'true',emptyValue='')""")
+                df_=self.hdfs2df(path[7:])
+            except:
+                print('查询失败')
+                df_='查询失败'
         self.client.delete(path[7:],recursive=True)
         return df_
+
+    def sql(self,sql):
+        seq=''.join(random.choices(list('ABCDEFGHJKLMNPQRSTUVWXYZ12345678901234567890'), k=5))
+        livyname=f"""{self.user}川A{seq}"""   
+        LIVY_SERVER = f"http://{self.host}:8998"
+        #auth = HTTPBasicAuth(self.user,self.password)
+        with LivySession.create(LIVY_SERVER,
+                                #auth=auth,
+                                verify=False,
+                                name=livyname,
+                                driver_memory="10g"
+                               ) as session:
+            try:
+                session.run(f"""spark.conf.set("hive.exec.dynamic.partition.mode", "nonstrict")""")
+                session.run(f"""spark.sql('''{sql}''')""")
+            except:
+                print('查询失败')
 if __name__ == '__main__':
-    pass
+    pass
\ No newline at end of file
